@@ -1,10 +1,11 @@
-use std::path::PathBuf;
+use super::Shell;
+use std::path::Path;
 
 #[derive(Debug)]
 pub struct Bash;
 
-impl super::shell::Shell for Bash {
-    fn path(&self, path: &PathBuf, append: bool) -> String {
+impl Shell for Bash {
+    fn path(&self, path: &Path, append: bool) -> String {
         if append {
             return format!("export PATH=$PATH:{:?};", path.display());
         }
